package de.mlessmann.certassist;

import static org.assertj.core.api.Assertions.assertThat;

import de.mlessmann.certassist.models.CertificateInfo;
import de.mlessmann.certassist.models.CertificateInfoExtension;
import de.mlessmann.certassist.models.CertificateInfoSubject;
import de.mlessmann.certassist.service.CertificateCreationService;
import java.nio.file.Path;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;

@SpringBootTest
public class CertificateServiceTest {

    @Autowired
    private CertificateCreationService certificateService;

    @Test
    void testCanCreateCertificate() {
        var request = CertificateInfo
            .builder()
            .type(CertificateInfo.RequestType.STANDALONE_CERTIFICATE)
            .subject(
                CertificateInfoSubject
                    .builder()
                    .commonName("cert.creation")
                    .country("DE")
                    .state("SH")
                    .locality("HH")
                    .organization("Crazy-Cats")
            )
            .extension(CertificateInfoExtension.builder().alternativeDnsNames("test2.home", "test3.home"))
            .build();
        var cert = certificateService.createCertificate(request);
        assertThat(cert).isNotNull();
        assertThat(cert.getId()).isGreaterThan("0");
    }

    @Test
    void testCanImportCertificate() {
        Path certDir = TestOpenSSLService.TEST_CERT_PATH;
        var importedCert = certificateService.importCertificate(
            certDir.resolve("x509forImport.pem"),
            certDir.resolve("x509forImport.key.pem"),
            TestOpenSSLService.TEST_CERT_PASSPHRASE
        );
        assertThat(importedCert).isNotNull();
        assertThat(importedCert.getId()).isGreaterThan("0");
    }
}
